@@ -37,15 +37,17 @@ public slots:
     void enableButtons();
     void resetButtonClicked();
     void minimizeButtonClicked();
-    void doAction1();
-    void doAction2();
-    void doAction3();
+    void doAction1();//Auto Rotation
+    void doAction2();//Manual Rotation
+    void doAction3();//Refresh Contacts
+    //void doAction4();//Options Menu
     void AddContact(QtMobility::QContact temp);
     void ContactUpdatesDone();
     void Copy_m_Contacts(QList<QtMobility::QContact>);
     void fetchContacts();
     void callNumber();
     void sendSMS();
+    void contactNameClicked();
     Q_SCRIPTABLE int top_application();
 
 signals:
